@@ -1,11 +1,11 @@
 #!/bin/sh
 #
-#   @(#)$Id: install.sh,v 1.12 2004/01/10 23:26:11 joerg78 Exp $
+#   @(#)$Id: install.sh,v 1.17.2.2 2004/10/17 20:29:07 joerg78 Exp $
 #
 #   cddbd - CD Database Protocol Server
 #
 #   Copyright (C) 1996  Steve Scherf (steve@moonsoft.com)
-#   Portions Copyright (C) 2001-2003  by various authors 
+#   Portions Copyright (C) 2001-2004  by various authors 
 #
 #   Based on the original source by Ti Kan.
 #
@@ -27,10 +27,19 @@
 PATH=/bin:/usr/bin:/sbin:/usr/sbin:/etc:/usr/local/bin:/usr/5bin
 export PATH
 
-CDDBD_VER=1.5PL2
+CDDBD_VER=1.5.1PL2
 ERRFILE=/tmp/cddbd.err
 TMPFILE=/tmp/cddbd.$$
 
+if [ -x cddbd.exe ]
+then
+    CDDBDEXEC=cddbd.exe
+else
+    CDDBDEXEC=cddbd
+fi
+
+MANPAGE=cddbd.1
+
 id=`id`
 
 # Set up access defaults.
@@ -80,7 +89,7 @@ doexit()
 {
 	if [ $1 -eq 0 ]
 	then
-		$ECHO "\nInstallation of cddbd is now complete."
+		$ECHO "\nInstallation of ${CDDBDEXEC} is now complete."
 	else
 		$ECHO "\nErrors have occurred in the installation."
 		if [ $ERRFILE != /dev/null ]
@@ -285,7 +294,7 @@ then
 	doexit 1
 fi
 
-if [ ! -x cddbd ]
+if [ ! -x ${CDDBDEXEC} ]
 then
 	$ECHO "You must make cddbd before installing."
 	doexit 1
@@ -308,7 +317,7 @@ then
 fi
 
 
-$ECHO "\nInstalling \"cddbd\" CDDB Protocol Server $CDDBD_VER by Steve Scherf et al."
+$ECHO "\nInstalling \"${CDDBDEXEC}\" CDDB Protocol Server $CDDBD_VER by Steve Scherf et al."
 
 
 # Determine BINDIR
@@ -331,6 +340,9 @@ else
 	BINDIR=`echo $BINDIR | sed 's/\/\//\//g'`
 fi
 
+# get the man path
+MANDIR=`echo $BINDIR | sed 's/bin$/man\/man1/g'`
+
 while :
 do
 	if getstr "\nEnter cddbd binary directory\n[${BINDIR}]:"
@@ -347,6 +359,22 @@ do
 	fi
 done
 
+while :
+do
+	if getstr "\nEnter cddbd man directory (for cddbd.1)\n[${MANDIR}]:"
+	then
+		if [ -d "$ANS" ]
+		then
+			MANDIR=$ANS
+			break
+		else
+			$ECHO "Error: $ANS does not exist."
+		fi
+	else
+		break
+	fi
+done
+
 
 # Find other directories
 
@@ -762,11 +790,15 @@ fi
 $ECHO "\nInstalling files..."
 
 # Binaries
-instfile cddbd ${BINDIR}/cddbd $BINPERM $OWNID $GRPID
+instfile ${CDDBDEXEC} ${BINDIR}/${CDDBDEXEC} $BINPERM $OWNID $GRPID
+
+# Man pages
+mkdir -p $MANDIR
+instfile ${MANPAGE} ${MANDIR}/${MANPAGE} $FILEPERM $OWNID $GRPID
 
 if [ "$CGIDIR" != "" ]
 then
-	instfile cddbd ${CGIDIR}/cddb.cgi $BINPERM $OWNID $GRPID
+	instfile ${CDDBDEXEC} ${CGIDIR}/cddb.cgi $BINPERM $OWNID $GRPID
 fi
 
 # Configuration files
@@ -785,7 +817,7 @@ then
 	$ECHO "\nPlease wait while the hash file is created."
 	$ECHO "This will take a few minutes.\n"
 
-	${BINDIR}/cddbd -fd
+	${BINDIR}/${CDDBDEXEC} -fd
 
 	err=$?
 	if [ $err -ne 0 ]
@@ -794,7 +826,7 @@ then
 	fi
 else
 	$ECHO "\nIf you wish to enable fuzzy matching in the future, you will"
-	$ECHO "have to run \"cddbd -fd\"."
+	$ECHO "have to run \"${CDDBDEXEC} -fd\"."
 fi
 
 doexit $ERROR
