@@ -21,8 +21,8 @@
  */
 
 #ifndef LINT
-static char *const _patchlevel_h_ident_ = "@(#)$Id: patchlevel.h,v 1.16 2004/01/10 23:26:11 joerg78 Exp $";
+static char *const _patchlevel_h_ident_ = "@(#)$Id: patchlevel.h,v 1.19.2.2 2004/10/16 22:15:56 megari Exp $";
 #endif
 
-#define VERSION		"1.5"	/* The version number. */
+#define VERSION		"1.5.1"	/* The version number. */
 #define PATCHLEVEL	2		/* The patch level. */
